@@ -10,7 +10,11 @@ from .exceptions import BadConfigError
 parser = argparse.ArgumentParser(
     prog='datavalid', description='validate CSV files')
 parser.add_argument(
-    "--dir", help="directory that contain datavalid.yml", type=pathlib.Path)
+    "--dir", help="directory that contain datavalid.yml", type=pathlib.Path
+)
+parser.add_argument(
+    "--doc", help="output markdown documentation to this file", type=pathlib.Path
+)
 args = parser.parse_args()
 if args.dir is None:
     datadir = pathlib.Path.cwd()
@@ -29,4 +33,8 @@ except BadConfigError as e:
     print("Error parsing config file %s:\n  %s" %
           (str(conf_file), str(e).replace('\n', '\n  ')))
     sys.exit(1)
-sys.exit(conf.run())
+if args.doc:
+    with open(args.doc, 'w') as f:
+        f.write(conf.to_markdown(args.doc.parent).strip()+'\n')
+else:
+    sys.exit(conf.run())
